@@ -1,6 +1,5 @@
 #----------------------------------------------------------------------
-# Nive cms
-# Copyright (C) 2012  Arndt Droullier, DV Electric, info@dvelectric.com
+# Copyright 2012, 2013 Arndt Droullier, Nive GmbH. All rights reserved.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,10 +15,11 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 #----------------------------------------------------------------------
 
-__version__ = "0.9.5b"
+__version__ = "0.9.9"
 __doc__ = """nive"""
 
 
 """
 Use `nive.definitions` to import Interfaces or Configuration classes
-"""
\ No newline at end of file
+"""
+from nive.utils.dataPool2.files import File
\ No newline at end of file
